textmining.TsujiiC3.GeniaObject

|  | ## Cheshire3 Object Model: Class GeniaObject

Package textmining :: Module TsujiiC3 :: Class GeniaObject

## Class GeniaObject
source code

Known Subclasses:
  tmNormalizer.ExactGeniaNormalizer, tmNormalizer.GeniaNormalizer, tmNormalizer.UnparsedGeniaNormalizer

Instance Methods

__init__(self, session, node, parent)
tag(self, session, data, xml=0)

Class Variables

inh |
outh |
tokenizer |

Method Details

### __init__(self, session, node, parent) (Constructor) | source code

### tag(self, session, data, xml=0) | source code

Class Variable Details

    ### inh Value:
        None

    ### outh Value:
        None

    ### tokenizer Value:
        None